@@ -250,6 +250,8 @@ class PyPDFOCR(object):
             for folder, keywords in self.config['folders'].items():
                 folder_count +=1
                 keyword_count += len(keywords)
+                # Make sure keywords are lower-cased before adding
+                keywords = [x.lower() for x in keywords]
                 self.filer.add_folder_target(folder, keywords)
 
         print ("Filing of PDFs is enabled")
